Pure Rust implementation of the Data Encryption Standard (DES), including Triple DES (TDES, 3DES) block ciphers.
⚠️ Security Warning: Hazmat!
This crate implements only the low-level block cipher function, and is intended for use for implementing higher-level constructions only. It is NOT intended for direct use in applications.
USE AT YOUR OWN RISK!
Re-exports
pub use cipher;
Structs
- Des
- Data Encryption Standard (DES) block cipher.
- Tdes
Ede2 - Triple DES (3DES) block cipher.
- Tdes
Ede3 - Triple DES (3DES) block cipher.
- Tdes
Eee2 - Triple DES (3DES) block cipher.
- Tdes
Eee3 - Triple DES (3DES) block cipher.
- Weak
KeyError - The error type returned when a key is found to be weak.
Functions
- weak_
key_ test - Checks whether
keycontains one of the known weak DES keys.